searchNodes=[{"doc":"Functions for parsing URLsThis module provides functions for parsing URLs. It is modelled on Elixir's URI module but will also parse scheme-specific URIs such as geo, data tel, mailto, and uuid.","ref":"URL.html","title":"URL","type":"module"},{"doc":"Parses a url and returns a %URL{} struct that has the same shape as Elixir's %URI{} with the addition of the parsed_path key.Example iex&gt; URL.parse(&quot;geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0&quot;) %URL{authority: nil, fragment: nil, host: nil, parsed_path: %URL.Geo{ alt: 3.4, lat: 48.198634, lng: -16.371648, params: %{&quot;crs&quot; =&gt; &quot;wgs84&quot;, &quot;u&quot; =&gt; 40.0} }, path: &quot;48.198634,-16.371648,3.4;crs=wgs84;u=40.0&quot;, port: nil, query: nil, scheme: &quot;geo&quot;, userinfo: nil }","ref":"URL.html#parse/1","title":"URL.parse/1","type":"function"},{"doc":"Parses the given binary as parse_query.Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the parse_query (start position) as {line, column_on_line}.Options:line - the initial line, defaults to 1:byte_offset - the initial byte offset, defaults to 0:context - the initial context value. It will be converted to a map","ref":"URL.html#parse_query/2","title":"URL.parse_query/2","type":"function"},{"doc":"Parse a URL query string and percent decode.ReturnsEither a map of query params oran {:error, {URL.Parser.ParseError, reason}} tupleExamplesiex&gt; URL.parse_query_string &quot;url=http%3a%2f%2ffonzi.com%2f&amp;name=Fonzi&amp;mood=happy&amp;coat=leather&quot; %{ &quot;coat&quot; =&gt; &quot;leather&quot;, &quot;mood&quot; =&gt; &quot;happy&quot;, &quot;name&quot; =&gt; &quot;Fonzi&quot;, &quot;url&quot; =&gt; &quot;http://fonzi.com/&quot; } iex&gt; mailto = &quot;mailto:user@%E7%B4%8D%E8%B1%86.example.org?subject=Test&amp;body=NATTO&quot; iex&gt; URL.parse(mailto) |&gt; URL.parse_query_string %{&quot;body&quot; =&gt; &quot;NATTO&quot;, &quot;subject&quot; =&gt; &quot;Test&quot;}","ref":"URL.html#parse_query_string/1","title":"URL.parse_query_string/1","type":"function"},{"doc":"See URI.to_string/1.","ref":"URL.html#to_string/1","title":"URL.to_string/1","type":"function"},{"doc":"","ref":"URL.html#t:t/0","title":"URL.t/0","type":"type"},{"doc":"","ref":"URL.html#t:uri_type/0","title":"URL.uri_type/0","type":"type"},{"doc":"Parses a data URL","ref":"URL.Data.html","title":"URL.Data","type":"module"},{"doc":"Parse a URI with the :scheme of &quot;data&quot;Exampleiex&gt; data = URI.parse &quot;data:text/plain;base64,SGVsbG8gV29ybGQh&quot; iex&gt; URL.Data.parse(data) %URL.Data{ data: &quot;Hello World!&quot;, mediatype: &quot;text/plain&quot;, params: %{&quot;encoding&quot; =&gt; &quot;base64&quot;} }","ref":"URL.Data.html#parse/1","title":"URL.Data.parse/1","type":"function"},{"doc":"","ref":"URL.Data.html#t:t/0","title":"URL.Data.t/0","type":"type"},{"doc":"Parses a geo URL","ref":"URL.Geo.html","title":"URL.Geo","type":"module"},{"doc":"Parse a URI with the :scheme of &quot;geo&quot;Exampleiex&gt; geo = URI.parse(&quot;geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0&quot;) iex&gt; URL.Geo.parse(geo) %URL.Geo{ alt: 3.4, lat: 48.198634, lng: -16.371648, params: %{&quot;crs&quot; =&gt; &quot;wgs84&quot;, &quot;u&quot; =&gt; 40.0} }","ref":"URL.Geo.html#parse/1","title":"URL.Geo.parse/1","type":"function"},{"doc":"","ref":"URL.Geo.html#t:t/0","title":"URL.Geo.t/0","type":"type"},{"doc":"Parses a mailto URL","ref":"URL.Mailto.html","title":"URL.Mailto","type":"module"},{"doc":"Parse a URI with the :scheme of &quot;tel&quot;Exampleiex&gt; mailto = URI.parse(&quot;mailto:user@%E7%B4%8D%E8%B1%86.example.org?subject=Test&amp;body=NATTO&quot;) iex&gt; URL.Mailto.parse(mailto) %URL.Mailto{ params: %{&quot;body&quot; =&gt; &quot;NATTO&quot;, &quot;subject&quot; =&gt; &quot;Test&quot;}, to: [&quot;user@納豆.example.org&quot;] }","ref":"URL.Mailto.html#parse/1","title":"URL.Mailto.parse/1","type":"function"},{"doc":"","ref":"URL.Mailto.html#t:t/0","title":"URL.Mailto.t/0","type":"type"},{"doc":"Parses a tel URL","ref":"URL.Tel.html","title":"URL.Tel","type":"module"},{"doc":"Parse a URI with the :scheme of &quot;tel&quot;Examplesiex&gt; tel = URI.parse &quot;tel:+61-0407-555-987&quot; iex&gt; URL.Tel.parse(tel) %URL.Tel{params: %{}, tel: &quot;+61 407 555 987&quot;} iex&gt; tel = URI.parse &quot;tel:0407-555-987;phone-context=+61&quot; iex&gt; URL.Tel.parse(tel) %URL.Tel{params: %{&quot;phone-context&quot; =&gt; &quot;+61&quot;}, tel: &quot;+61 407 555 987&quot;}","ref":"URL.Tel.html#parse/1","title":"URL.Tel.parse/1","type":"function"},{"doc":"","ref":"URL.Tel.html#t:t/0","title":"URL.Tel.t/0","type":"type"},{"doc":"Parses a geo URL","ref":"URL.UUID.html","title":"URL.UUID","type":"module"},{"doc":"Parse a URI with the :scheme of &quot;uuid&quot;Exampleiex&gt; uuid = URI.parse(&quot;uuid:f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b&quot;) iex&gt; URL.UUID.parse(uuid) %URL.UUID{params: %{&quot;a&quot; =&gt; &quot;b&quot;}, uuid: &quot;f81d4fae-7dec-11d0-a765-00a0c91e6bf6&quot;} iex&gt; uuid = URI.parse(&quot;urn:uuid:f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b&quot;) iex&gt; URL.UUID.parse(uuid) %URL.UUID{params: %{&quot;a&quot; =&gt; &quot;b&quot;}, uuid: &quot;f81d4fae-7dec-11d0-a765-00a0c91e6bf6&quot;}","ref":"URL.UUID.html#parse/1","title":"URL.UUID.parse/1","type":"function"},{"doc":"","ref":"URL.UUID.html#t:t/0","title":"URL.UUID.t/0","type":"type"},{"doc":"Exception raised when a URL cannot be parsed","ref":"URL.Parser.ParseError.html","title":"URL.Parser.ParseError","type":"exception"},{"doc":"Getting Started","ref":"readme.html","title":"Getting Started","type":"extras"},{"doc":"ex_url is a library modelled on the Elixir URI module. It parses and formats URL's with the additional function that is parses the scheme-specific payload of known URI schemes. At present it can parse:geodatamailtouuidand telThe basic API is URL.parse/1. The function URL.to_string/1 is delegated to the URI module.Of course these are really URI's, not URL's but its a reasonable choice of name given that WHATWG prefers URL over URI:Standardize on the term URL. URI and IRI [Internationalized Resource Identifier] are just confusing. In practice a single algorithm is used for both so keeping them distinct is not helping anyone. URL also easily wins the search result popularity contest","ref":"readme.html#overview","title":"Getting Started - Overview","type":"extras"},{"doc":"Parse a geo URL:iex&gt; URL.parse(&quot;geo:48.198634,-16.371648,3.4;crs=wgs84;u=40.0&quot;) %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.Geo{ alt: 3.4, lat: 48.198634, lng: -16.371648, params: %{&quot;crs&quot; =&gt; &quot;wgs84&quot;, &quot;u&quot; =&gt; 40.0} }, path: &quot;48.198634,-16.371648,3.4;crs=wgs84;u=40.0&quot;, port: nil, query: nil, scheme: &quot;geo&quot;, userinfo: nil }Parse a tel URL:iex&gt; URL.parse(&quot;tel:+61-0407-555-987&quot;) %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.Tel{params: %{}, tel: &quot;+61 407 555 987&quot;}, path: &quot;+61-0407-555-987&quot;, port: nil, query: nil, scheme: &quot;tel&quot;, userinfo: nil } # When the parameter &quot;phone-context&quot; is also a valid number then it is prepended before formatting iex&gt; tel = URL.parse &quot;tel:0407-555-987;phone-context=+61&quot; %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.Tel{ params: %{&quot;phone-context&quot; =&gt; &quot;+61&quot;}, tel: &quot;+61 407 555 987&quot; }, path: &quot;0407-555-987;phone-context=+61&quot;, port: nil, query: nil, scheme: &quot;tel&quot;, userinfo: nil }Parse a data URL:This first example shows the treatment of data that is base64 encoded. It is decoded by URL.Data.parse/1.iex&gt; URL.parse(&quot;data:;base64,SGVsbG8gV29ybGQh&quot;) %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.Data{ data: &quot;Hello World!&quot;, mediatype: &quot;text/plain&quot;, params: %{&quot;encoding&quot; =&gt; &quot;base64&quot;} }, path: &quot;;base64,SGVsbG8gV29ybGQh&quot;, port: nil, query: nil, scheme: &quot;data&quot;, userinfo: nil }This second example shows the treatment of data that is not marked as base64 encoded. In this case it is considered to be percent-encoded. It is also decoded during parsing.iex&gt; URL.parse(&quot;data:,Hello%20World%21&quot;) %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.Data{ data: &quot;Hello World!&quot;, mediatype: &quot;text/plain&quot;, params: %{} }, path: &quot;,Hello%20World%21&quot;, port: nil, query: nil, scheme: &quot;data&quot;, userinfo: nil }Parse a mailto URLA mailto URL will be parsed and percent encoding will be decoded. Note that RFC2047 encoded-words is not currently supported.iex&gt; URL.parse &quot;mailto:infobot@example.com?subject=current-issue&quot; %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.Mailto{ params: %{&quot;subject&quot; =&gt; &quot;current-issue&quot;}, to: [&quot;infobot@example.com&quot;] }, path: &quot;infobot@example.com&quot;, port: nil, query: &quot;subject=current-issue&quot;, scheme: &quot;mailto&quot;, userinfo: nil }Parse a uuid URLiex&gt; URL.parse &quot;uuid:f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b&quot; %URL{ authority: nil, fragment: nil, host: nil, parsed_path: %URL.UUID{ params: %{&quot;a&quot; =&gt; &quot;b&quot;}, uuid: &quot;f81d4fae-7dec-11d0-a765-00a0c91e6bf6&quot; }, path: &quot;f81d4fae-7dec-11d0-a765-00a0c91e6bf6;a=b&quot;, port: nil, query: nil, scheme: &quot;uuid&quot;, userinfo: nil }","ref":"readme.html#examples","title":"Getting Started - Examples","type":"extras"},{"doc":"Configure ex_url in mix.exs: defp deps do [ {:ex_url, &quot;~&gt; 0.3&quot;}, ... ] endIf configured in mix.exs, URL will use the following libraries:ex_phone_number will be used to parse and format telephone numbers defined in the tel URI schemeex_cldr and gettext will be used to determine the current locale and therefore the current territory (country) for parsing and formatting telephone numbers that don't have a country code supplied.Optional configuration in mix.exs: defp deps do [ # Required {:ex_url, &quot;~&gt; 1.3&quot;}, # Optional {:ex_phone_number, &quot;~&gt; 0.1&quot;}, {:ex_cldr, &quot;~&gt; 2.18&quot;}, {:gettext, &quot;~&gt; 0.13&quot;} ... ] end","ref":"readme.html#configuration","title":"Getting Started - Configuration","type":"extras"},{"doc":"LicenseCopyright 2018 Kip ColeLicensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License athttp://www.apache.org/licenses/LICENSE-2.0Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"Changelog for URL v1.3.0This is the changelog for URL version 1.3.0 released on November 1st. For older changelogs please consult the release tag on GitHubEnhancementsSupport CLDR 38Bug FixesCorrect some types to use map()Fix error resulting from inconsistent use of territories as atoms and stringsChangelog for URL v1.2.0This is the changelog for URL version 1.2.0 released on January 23rd, 2020. For older changelogs please consult the release tag on GitHubEnhancementsExecutes String.trim/1 on parsed elements of URI's so that &quot;https:// google.fr&quot; will return &quot;google.fr&quot; as the host, not &quot; google.fr&quot;.Changelog for URL v1.1.0This is the changelog for URL version 1.1.0 released on April 7th, 2019. For older changelogs please consult the release tag on GitHubEnhancementsUpdate to NimbleParsec version 0.5Changelog for URL v1.0.0This is the changelog for URL version 1.0.0 released on November 25th, 2018. For older changelogs please consult the release tag on GitHubEnhancementsSupports ex_cldr version 2.0.0. This is an optional dependency.Add URL.parse_query_string/1Changelog for URL v0.4.0This is the changelog for URL version 0.4.0 released on October 18th, 2018. For older changelogs please consult the release tag on GitHubEnhancementsAdds support for the uuid URL type. See URL.UUIDChangelog for URL v0.3.0This is the changelog for URL version 0.3.0 released on October 16th, 2018. For older changelogs please consult the release tag on GitHubEnhancementsAdds support for the mailto URL type. See URL.MailtoBug FixesNow correctly uses the phone-context parameter when formatting a telelphone number in a tel URL.Changelog for URL v0.2.0This is the changelog for URL version 0.2.0 released on October 13th, 2018. For older changelogs please consult the release tag on GitHubEnhancementsAdd specs to public functionsMake several functions private including the defparsec definitionsChangelog for URL v0.1.0This is the changelog for URL version 0.1.0 released on October 13th, 2018. For older changelogs please consult the release tag on GitHubEnhancementsInitial release of URL","ref":"changelog.html","title":"Changelog for URL v1.3.0","type":"extras"}]